@@ -1,5 +1,5 @@
 from .video import *
 from .option import Option
-import utils
+from . import utils
 from .model_schema import *
 from .fps_writer import FpsDrawer
\ No newline at end of file
